const vec4 tone1 = vec4(0.8, 0.0, 0.0, 1.0);
const vec4 tone2 = vec4(1.0, 0.8, 0.0, 1.0);

varying vec3 V_eye;
varying vec3 L_eye;
varying vec3 N_eye;

void main()
{
	vec3 V = normalize(V_eye);
	vec3 L = normalize(L_eye);
	vec3 N = normalize(N_eye);

	float NdotL = dot(L, N);
	
	// Ambient light
	gl_FragColor = tone1*0.2;

	if (NdotL>0.0)
	{
		// Two tone paint (Diffuse light)
		float NdotV = dot(N, V);
		gl_FragColor += mix(tone1, tone2, NdotV*NdotV) * NdotL;

		// Sharp specular light
		vec3 R = (2.0*NdotL)*N - L;
		float specular = pow(max(0.0, dot(R, V)), 64.0);
		specular = smoothstep(0.5, 0.75, specular);
		gl_FragColor += specular;
	}
}
